# UpdateIndicatorReputationData

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**investigation_id** | **str** |  | [optional] 
**do_not_whitelist** | **bool** |  | [optional] 
**entry_id** | **str** |  | [optional] 
**manual_score** | **bool** |  | [optional] 
**reason** | **str** |  | [optional] 
**reputation** | **int** |  | [optional] 
**reputations** | **list[str]** |  | [optional] 
**value** | **str** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


